@@ -67,21 +67,29 @@ class KhtTextEdit( QPlainTextEdit):
         else:
             self.setLineWrapMode( QPlainTextEdit.WidgetWidth)
 
+        font =  QFont()
+        try:
+            if parent.settings.contains('FontName'):       
+                font.setFamily(parent.settings.value('FontName'))
+            else:
+                font.setFamily("Courier")
+        except:
+            font.setFamily("Courier")
+            
+        font.setFixedPitch(True)
+        font.setPointSize(12)
+
         #Get Font Size
         try:
-            fontsize = int(parent.settings.value("FontSize"))
+            if parent.settings.contains('FontSize'):
+                font.setPointSize(int(parent.settings.value('FontSize')))
+            else:
+                font.setPointSize(11)
         except:
-            fontsize = 11
+            font.setPointSize(11)
             
-        if fontsize==0:
-            fontsize=11
-        #Get Font
-        try:
-            fontname = parent.settings.value("FontName").toString()
-        except:
-            fontname = 'Monospace'
         #Set Font
-        self.document().setDefaultFont( QFont(fontname,fontsize))
+        self.document().setDefaultFont( font)
         
 
         #Remove auto capitalization
