@@ -202,7 +202,7 @@ class Window( QMainWindow):
         self.setupFileMenu()
         self.setupHelpMenu()
         self.setupEditor()
-
+        
         try:
             self.setAttribute( Qt.WA_Maemo5AutoOrientation, True)
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
@@ -275,13 +275,13 @@ class Window( QMainWindow):
                     "Failed to load %s: %s" % (filename, e))
 
     def setupEditor(self):
-        font =  QFont()
-        font.setFamily("Courier")
-        font.setFixedPitch(True)
-        font.setPointSize(12)
+#        font =  QFont()
+#        font.setFamily("Courier")
+#        font.setFixedPitch(True)
+#        font.setPointSize(12)
 
         self.editor = editor.KhtTextEdit(self)
-        self.editor.setFont(font)
+#        self.editor.setFont(font)
         #self.editor_frame = editor_frame.Frame(self.editor)
         self.setupToolBar()
 #        self.language = self.detectLanguage()
@@ -432,7 +432,11 @@ class Window( QMainWindow):
               if language == 'python':
                 fileHandle.write("python \'"+unicode(self.editor.filename).encode('utf-8') + "\'\n")
               elif language == 'qml':
-                fileHandle.write("qmlviewer \'"+unicode(self.editor.filename).encode('utf-8') + "\' -fullscreen\n")             
+                fileHandle.write("qmlviewer \'"+unicode(self.editor.filename).encode('utf-8') + "\' -fullscreen\n")      
+              elif language in ('c', 'cpp'):
+                fileHandle.write("make %s\nchmod +x %s\n./%s" % (unicode(self.editor.filename).encode('utf-8'),\
+                                                                 unicode(self.editor.filename).encode('utf-8'),\
+                                                                 unicode(self.editor.filename).encode('utf-8')))       
               elif language != None:
                 fileHandle.write(language+" \'"+unicode(self.editor.filename).encode('utf-8') + "\' \n")
               else:
@@ -442,7 +446,7 @@ class Window( QMainWindow):
               fileHandle.close()
           except (IOError, OSError), e:
              QMessageBox.warning(self, "KhtEditor -- Execute Error",
-                    "Failed to write launch script %s: %s" % (filename, e))
+                    "Failed to write launch script %s: %s" % (self.editor.filename, e))
           commands.getoutput("chmod 777 /tmp/khteditor.tmp")
           Popen('/usr/bin/osso-xterm /tmp/khteditor.tmp',shell=True,stdout=None)
 
